@@ -26,6 +26,7 @@ class BaseDeployment(object):
     project_dir = None
     virtualenv_dir = None
     mode = 0777
+    settings = "settings"
 
     def __init__(self, deployment, project_dir, deployment_dir):
         self.deployment = deployment
@@ -166,7 +167,7 @@ class BaseDeployment(object):
         """
         full_manage_dir = Path(self.target_dir, Path(self.manage_dir))
         with virtualenv(str(self.virtualenv_dir), full_manage_dir):
-            sudo('manage.py %s' % arg)
+            sudo('manage.py %s --settings=%s' % (arg, self.settings))
 
     @easyfabtask
     def upgrade_requirements(self):
